@@ -32,18 +32,11 @@
 
 class SpectatorPlayer : public LocalPlayer
 {
-    Q_OBJECT
-
 public:
     explicit SpectatorPlayer(Game *game, const QString &newName, const QColor &color);
 
-    virtual bool isDead();
-    virtual bool isSpectator();
-
-signals:
-
-public slots:
-
+    bool isDead() override;
+    bool isSpectator() override;
 };
 
 #endif // SPECTATORPLAYER_H
